@@ -158,7 +158,9 @@ const.APP_SETTINGS = 'APP_SETTINGS'
 const.USERS_INFO = 'USERS_INFO'
 
 # API GW
+const.CODO_API_GW = 'api_gw'
 const.WEBSITE_API_GW_URL = 'api_gw'
+const.CODO_OUTER_API_GW = 'outer_api_gw'
 const.API_AUTH_KEY = 'settings_auth_key'
 const.EMAILLOGIN_DOMAIN = 'EMAILLOGIN_DOMAIN'
 const.EMAILLOGIN_SERVER = 'EMAILLOGIN_SERVER'
@@ -179,8 +181,23 @@ const.SMS_DOMAIN = "SMS_DOMAIN"
 
 const.SMS_ACCESS_KEY_ID = 'SMS_ACCESS_KEY_ID'
 const.SMS_ACCESS_KEY_SECRET = 'SMS_ACCESS_KEY_SECRET'
+
 # 钉钉
-const.DING_TALK_WEBHOOK = "DING_TALK_WEBHOOK"
+const.DINGTALK_CLIENT_ID = "dingtalk_client_id"
+const.DINGTALK_CLIENT_SECRET = "dingtalk_client_secret"
+const.DINGTALK_AGENT_ID = "dingtalk_agent_id"
+const.DINGTALK_AUTH = "dingtalk_auth"
+
+# 飞书
+const.FEISHU_CLIENT_ID = "feishu_client_id"
+const.FEISHU_CLIENT_SECRET = "feishu_client_secret"
+const.FEISHU_AUTH = "feishu_auth"
+
+# 企微
+const.WECHATWORK_CORP_ID = "wechatwork_corp_id"
+const.WECHATWORK_AGENT_ID = "wechatwork_agent_id"
+const.WECHATWORK_AUTH = "wechatwork_auth"
+
 # 存储
 const.STORAGE_REGION = "STORAGE_REGION"
 const.STORAGE_NAME = "STORAGE_NAME"
@@ -199,11 +216,12 @@ const.LDAP_ATTRIBUTES = "LDAP_ATTRIBUTES"
 const.LDAP_USE_SSL = "LDAP_USE_SSL"
 const.LDAP_ENABLE = "LDAP_ENABLE"
 
-### token 超时时间
+# token 超时时间
 const.TOKEN_EXP_TIME = "TOKEN_EXP_TIME"
 
-### 全局 二次认证
-const.MFA_GLOBAL = 'MFA_GLOBAL'
+# 二次认证
+const.MFA_GLOBAL = 'MFA_GLOBAL'  # 全局开启
+const.MFA_ADMIN_ONLY = 'MFA_ADMIN_ONLY'  # 管理员开启
 
 # task event 状态
 const.STATE_NEW = '0'  # 新建任务
